package Sample::Module;

use strict;
use warnings;

1;

__END__

=head1 NAME

Sample::Module - Sample Module

=head1 SYNOPSIS

  blah blah blah

=head1 SEE ALSO

L<Sample::Project>

=head1 SOME "DIFFICULT" NODE WITH SPACES
