package Sample::Project;

use strict;
use warnings;

1;

__END__

=head1 NAME

Sample::Project - Sample project for testing Pod::ProjectDocs

=head1 SYNOPSIS

  blah blah blah mäh

=head1 DESCRIPTION

I<foo>. See L</SYNOPSIS> for its usage and L<Sample::Module/SYNOPSIS> for Sample::Module.

=head1 SEE ALSO

L<perl>, L<Sample::Module>, L<Pod::ProjectDocs>, L<http://www.perl.org/>, L<Perl POD Syntax|perlpod>

=head1 SOME "DIFFICULT" NODE WITH SPACES

L<Sample::Module/SOME "DIFFICULT" NODE WITH SPACES>
